==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=bs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Vazna grupa:</b> savjetuje se da izaberete kljucnu rijec za ovu grupu.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratori stranice',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'urendici',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'posjetitelji stranice za publiku, ako postavljaju poruku u  forum.',

	// I
	'icone_creation_groupe_mots' => 'Kreiraj novu grupu rijeci',
	'icone_creation_mots_cles' => 'Kreiraj novu lozinku',
	'icone_modif_groupe_mots' => 'Izmijeni ovu grupu rijeci',
	'icone_mots_cles' => 'Kljucne rijeci',
	'icone_supprimer_groupe_mots' => 'Izbrisi ovu grupu',
	'icone_voir_tous_mots_cles' => 'Pogledaj sve kljucne rijeci',
	'info_articles_lies_mot' => 'Clanci vezani za ovu kljucnu rijec',
	'info_changer_nom_groupe' => 'Promijeniti ime ove grupe:',
	'info_creation_mots_cles' => 'Ovdje mozete kreirati i konfigurisati kljucne rijeci stranice',
	'info_dans_groupe' => 'U grupi:',
	'info_delet_mots_cles' => 'Zelite izbrisati ovu kljucnu rijec  <b>@titre_mot@</b> (@type_mot@). Ova kljucna rijec je vezana za  <b>@texte_lie@</b> zelite li potvrditi ovu odluku:', # MODIF
	'info_groupe_important' => 'Vazna grupa',
	'info_mots_cles' => 'Kljucne rijeci',
	'info_mots_cles_association' => 'Kljucne rijeci ove grupe mogu  biti asocirane sa:',
	'info_oui_suppression_mot_cle' => 'definitivno izbrisati ovu kljucnu rijec.',
	'info_question_mots_cles' => 'Zelite li koristiti kljucne rijeci na vasoj stranici?',
	'info_qui_attribue_mot_cle' => 'Rijeci ove grupe mogu biti dodane od strane:',
	'info_retirer_mot' => 'Odstrani ovu kljucnu rijec',
	'info_retirer_mots' => 'Odstrani sve kljucne rijeci',
	'info_rubriques_liees_mot' => 'Rubrike vezane za ovu kljucnu rijec',
	'info_selection_un_seul_mot_cle' => 'Moguce je izabrati <b>samo po jednu kljucnu rijec</b> u ovoj grupi.', # MODIF
	'info_supprimer_mot' => 'Izbrisati ovu rijec',
	'info_titre_mot_cle' => 'Ime ili naslov kljucne rijeci',
	'info_un_mot' => 'Samo po jedna rijec',
	'item_ajout_mots_cles' => 'Odobri dodavanje kljucnih rijeci u forum',
	'item_non_ajout_mots_cles' => 'Zabrani upotrebu kljucnih rijeci u forumu',
	'item_non_utiliser_config_groupe_mots_cles' => 'Ne koristi naprednu konfiguraciju grupa kljucnih rijeci',
	'item_non_utiliser_mots_cles' => 'Ne koristi kljucne rijeci',
	'item_utiliser_config_groupe_mots_cles' => 'Koristi naprednu konfiguraciju grupa kljucnih rijeci',
	'item_utiliser_mots_cles' => 'Koristi kljucne rijeci',

	// L
	'logo_mot_cle' => 'LOGOTIP KLJUCNE RIJECI',

	// T
	'texte_config_groupe_mots_cles' => 'Da li zelite aktivirati naprednu konfiguraciju kljucnih rijeci, sto znaci da je moguce izabrati jednu rijec po grupi, da je jedna grupa vazna...?', # MODIF
	'texte_mots_cles' => 'Kljucne rijeci omogucuju kreiranje tematskih veza izmedju vasih clanaka, neovisno o njihovom  mjestu u rubrikama. Tako mozete obogatiti navigaciju na vasoj  stranici i cak koristiti ovu opciju personalizovali prezentaciju clanaka u vasim obrascima.',
	'texte_mots_cles_dans_forum' => 'Da li zelite odobriti koristenje kljucnih rijeci (posjetioci mogu izabrati iste) u  forumima javne stranice? (Paznja: ova opcija relativno slozena za ispravno koristenje.)', # MODIF
	'texte_nouveau_mot' => 'Nova rijec',
	'titre_config_groupe_mots_cles' => 'Konfiguracija grupa kljucnih rijeci',
	'titre_gauche_mots_edit' => 'RIJEC BROJ:',
	'titre_mots_cles_dans_forum' => 'Kljucne rijeci u forumu javne stranice',
	'titre_mots_tous' => 'Kljucne rijeci',
	'titre_nouveau_groupe' => 'Nova grupa',
	'titre_page_mots_tous' => 'Kljucne rijeci'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=bs
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Vazna grupa:</b> savjetuje se da izaberete kljucnu rijec za ovu grupu.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratori stranice',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'urendici',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'posjetitelji stranice za publiku, ako postavljaju poruku u  forum.',

	// I
	'icone_creation_groupe_mots' => 'Kreiraj novu grupu rijeci',
	'icone_creation_mots_cles' => 'Kreiraj novu lozinku',
	'icone_modif_groupe_mots' => 'Izmijeni ovu grupu rijeci',
	'icone_mots_cles' => 'Kljucne rijeci',
	'icone_supprimer_groupe_mots' => 'Izbrisi ovu grupu',
	'icone_voir_tous_mots_cles' => 'Pogledaj sve kljucne rijeci',
	'info_articles_lies_mot' => 'Clanci vezani za ovu kljucnu rijec',
	'info_changer_nom_groupe' => 'Promijeniti ime ove grupe:',
	'info_creation_mots_cles' => 'Ovdje mozete kreirati i konfigurisati kljucne rijeci stranice',
	'info_dans_groupe' => 'U grupi:',
	'info_delet_mots_cles' => 'Zelite izbrisati ovu kljucnu rijec  <b>@titre_mot@</b> (@type_mot@). Ova kljucna rijec je vezana za  <b>@texte_lie@</b> zelite li potvrditi ovu odluku:', # MODIF
	'info_groupe_important' => 'Vazna grupa',
	'info_mots_cles' => 'Kljucne rijeci',
	'info_mots_cles_association' => 'Kljucne rijeci ove grupe mogu  biti asocirane sa:',
	'info_oui_suppression_mot_cle' => 'definitivno izbrisati ovu kljucnu rijec.',
	'info_question_mots_cles' => 'Zelite li koristiti kljucne rijeci na vasoj stranici?',
	'info_qui_attribue_mot_cle' => 'Rijeci ove grupe mogu biti dodane od strane:',
	'info_retirer_mot' => 'Odstrani ovu kljucnu rijec',
	'info_retirer_mots' => 'Odstrani sve kljucne rijeci',
	'info_rubriques_liees_mot' => 'Rubrike vezane za ovu kljucnu rijec',
	'info_selection_un_seul_mot_cle' => 'Moguce je izabrati <b>samo po jednu kljucnu rijec</b> u ovoj grupi.', # MODIF
	'info_supprimer_mot' => 'Izbrisati ovu rijec',
	'info_titre_mot_cle' => 'Ime ili naslov kljucne rijeci',
	'info_un_mot' => 'Samo po jedna rijec',
	'item_ajout_mots_cles' => 'Odobri dodavanje kljucnih rijeci u forum',
	'item_non_ajout_mots_cles' => 'Zabrani upotrebu kljucnih rijeci u forumu',
	'item_non_utiliser_config_groupe_mots_cles' => 'Ne koristi naprednu konfiguraciju grupa kljucnih rijeci',
	'item_non_utiliser_mots_cles' => 'Ne koristi kljucne rijeci',
	'item_utiliser_config_groupe_mots_cles' => 'Koristi naprednu konfiguraciju grupa kljucnih rijeci',
	'item_utiliser_mots_cles' => 'Koristi kljucne rijeci',

	// L
	'logo_mot_cle' => 'LOGOTIP KLJUCNE RIJECI',

	// T
	'texte_config_groupe_mots_cles' => 'Da li zelite aktivirati naprednu konfiguraciju kljucnih rijeci, sto znaci da je moguce izabrati jednu rijec po grupi, da je jedna grupa vazna...?', # MODIF
	'texte_mots_cles' => 'Kljucne rijeci omogucuju kreiranje tematskih veza izmedju vasih clanaka, neovisno o njihovom  mjestu u rubrikama. Tako mozete obogatiti navigaciju na vasoj  stranici i cak koristiti ovu opciju personalizovali prezentaciju clanaka u vasim obrascima.',
	'texte_mots_cles_dans_forum' => 'Da li zelite odobriti koristenje kljucnih rijeci (posjetioci mogu izabrati iste) u  forumima javne stranice? (Paznja: ova opcija relativno slozena za ispravno koristenje.)', # MODIF
	'texte_nouveau_mot' => 'Nova rijec',
	'titre_config_groupe_mots_cles' => 'Konfiguracija grupa kljucnih rijeci',
	'titre_gauche_mots_edit' => 'RIJEC BROJ:',
	'titre_mots_cles_dans_forum' => 'Kljucne rijeci u forumu javne stranice',
	'titre_mots_tous' => 'Kljucne rijeci',
	'titre_nouveau_groupe' => 'Nova grupa',
	'titre_page_mots_tous' => 'Kljucne rijeci',
];
